=====
macOS
=====

The default output format for macOS is an :doc:`app <./app>`.

Briefcase also supports creating an :doc:`Xcode project <./xcode>`
which in turn can be used to build an app.

Both output formats support packaging as a macOS DMG or as a standalone
signed app bundle.

.. toctree::
   :maxdepth: 1

   app
   xcode
